.. _module-docs:

API Reference
=============

Because every feature of PyMoskito must have a test case, when you are not sure how
to use something, just look into the ``tests/`` directories, find that feature
and read the tests for it, that will tell you everything you need to know.

Most of the things are already documented though in this document, that is
automatically generated using PyMoskito's docstrings.

Click the  "modules" (:ref:`modindex`) link in the top right corner to easily
access any PyMoskito module, or use this contents:

.. toctree::
    :maxdepth: 2

    simulation_gui
    simulation_modules
    generic_simulation_modules
    simulation_core
    processing_gui
    processing_core
    controltools
    tools
